KXHUmNWwnQeuAnPI class abstract

Implementers

Constructors

KXHUmNWwnQeuAnPI()

Properties

GoeBWmFDCfBYIvZi ↔ void Function(List<YIMMessage> messages)?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ikSHWWPGWHforjmp ↔ void Function(YIMRevokeMessage revokeMessage)?
getter/setter pair
jPdLbUypmmQtmVjx ↔ void Function(String roomID)?
getter/setter pair
KXlchqmQVBmarQpB ↔ void Function(List<YIMMessage> messages)?
getter/setter pair
OExbLpZHFKVLSOZn ↔ void Function(YIMResult<YIMEnum_OnlineState> result)?
getter/setter pair
prxHFQqFXpSrwAGV ↔ void Function(YIMBroadcastMessage broadcastMessage)?
getter/setter pair
RgYtQzzzClMOMYUM ↔ void Function(YIMNotificationMessage notificationMessage)?
getter/setter pair
ROKWPnmihOLqdWTE ↔ void Function(YIMPushMessage pushMessage)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
TFaKuGDVFUgNDFNm ↔ void Function(List<YIMConversation> conversations)?
getter/setter pair
UuYFyMelxcIiuATS ↔ void Function()?
getter/setter pair
WXBRvbiPvYYuBfEB ↔ void Function(List<YIMConversation> conversations)?
getter/setter pair
yjsVNFOgyFcFDUjI ↔ void Function(List<YIMConversation> conversations)?
getter/setter pair
yVDNAuJFzxuENoPh ↔ void Function(String roomID)?
getter/setter pair
zHgleWmPuHcFiIOd ↔ void Function(String conversationID)?
getter/setter pair

Methods

AbQMGnGwsAwcexHZ() → void
cSmgaWTKFYpRdgFv({required void fDsWzZmHzuvhjHYF(YIMResult<YIMEnum_OnlineState> result)}) → void
DdXGhAoSuhQkPzMv() → void
dLNsETLELSVhsMMk({required void fDsWzZmHzuvhjHYF(List<YIMMessage> messages)}) → void
dqertosKuXMnyjpt() → void
EhQegaMtkKEZgiVQ({required void fDsWzZmHzuvhjHYF(List<YIMConversation> conversations)}) → void
GmdlPeWdicDQHVte() → void
GWTBWwHhCrSIoagp() → void
HmrYpeCXZGEEbcsz() → void
HsoKVVrpMNesNilk({required void fDsWzZmHzuvhjHYF(List<YIMMessage> messages)}) → void
iSgfZMWlJVTWrAnh({required void fDsWzZmHzuvhjHYF(YIMRevokeMessage revokeMessage)}) → void
LbFHhmxfTNodLmPE() → void
MaIByHBnGlWekooi({required void fDsWzZmHzuvhjHYF(List<YIMConversation> conversations)}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
OjgrYdTWsqmeuyFD({required void fDsWzZmHzuvhjHYF()}) → void
plJDekdTCZFOpRde() → void
pUfbSIFjOqyWyazw({required void fDsWzZmHzuvhjHYF(YIMPushMessage pushMessage)}) → void
qcruBXGbIVzSuNhf() → void
rHcAzEEqeaueuOMX({required void fDsWzZmHzuvhjHYF(YIMBroadcastMessage broadcastMessage)}) → void
RHNkfEyGUgQSOlSy() → void
toString() String
A string representation of this object.
inherited
uAvtaORkmkpRGhuh({required void fDsWzZmHzuvhjHYF(String conversationID)}) → void
UjOsygOHpDAkuwbV() → void
VXdqdhCyfjJqkxoW({required void fDsWzZmHzuvhjHYF(String roomID)}) → void
WWyiwOlNmjGwvSmO() → void
xgcutvtAymwQnjUx({required void fDsWzZmHzuvhjHYF(List<YIMConversation> conversations)}) → void
XnCSyoDMHvWwlOpC({required void fDsWzZmHzuvhjHYF(YIMNotificationMessage notificationMessage)}) → void
YmzcdaVnooNfdMlx() → void
yobfvKFrukFquATf({required void fDsWzZmHzuvhjHYF(String roomID)}) → void
yqcKMWBYTBEVuauI() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited