pgKLSGlnZXDFodab class

Constructors

pgKLSGlnZXDFodab()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
YQHohvOQMIynSgHM Map<String, Database>
getter/setter pair

Methods

arlKVgBJVOfgnBoJ() → void
bmENyNbEhRkTDKiK(_YIMTableName vVtNDckWseWjvugN, Map<String, dynamic> BXHLIlLMBciXCCzz(), {Finder? bNcvVipPUFFpNiXa}) Future<bool>
kaxlmXwIPSTNMPFk() → StoreRef<int, Map<String, Object?>>
MMvaTHZPrveZgyUT(_YIMTableName vVtNDckWseWjvugN) Future<Database?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
NTJsTOZDYpjQplsE<T extends aupiTNESLKLnljXL>(_YIMTableName vVtNDckWseWjvugN, T BXHLIlLMBciXCCzz(T? rFbpbySHruxzmGYR), {Finder? bNcvVipPUFFpNiXa, required dynamic BozapwVfDLDEsXet(dynamic map)?}) Future<bool>
QgBzKiNpnHcBSCXv(_YIMTableName tableName, {Filter? filter}) Future<int?>
SeJaoOYwfIiXMvyG(_YIMTableName vVtNDckWseWjvugN, {Finder? bNcvVipPUFFpNiXa}) Future<bool>
tcrpGsqmIoDlHQex<T extends aupiTNESLKLnljXL>(_YIMTableName vVtNDckWseWjvugN, T BXHLIlLMBciXCCzz(T? qvmaWLIAPrHSyTjt), {Finder? bNcvVipPUFFpNiXa, required dynamic BozapwVfDLDEsXet(dynamic HtyHNKArhwxRaIIo)?}) Future<bool>
toString() String
A string representation of this object.
inherited
wanYqaCFigqxxdwW<T extends aupiTNESLKLnljXL>(_YIMTableName vVtNDckWseWjvugN, {Finder? bNcvVipPUFFpNiXa, required dynamic BozapwVfDLDEsXet(dynamic HtyHNKArhwxRaIIo)?}) Future<List<T>?>
xHLoiYMIgKDYsInU(_YIMTableName vVtNDckWseWjvugN, {aupiTNESLKLnljXL? rFbpbySHruxzmGYR, List<aupiTNESLKLnljXL>? rkCFnmjVLEnYXChs}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited