zLPFaXXYcXAYRhRd class abstract

Implementers

Constructors

zLPFaXXYcXAYRhRd()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
RyACsHXAfcHwqfQv Set<String>
final
zEpfxXprHiKaSqtJ ↔ void Function(String user, YIMEnum_EventOnline event)?
getter/setter pair

Methods

deDjvZFQGSIglhZK({required List<String> bziQtUQwwnoMJBAJ, void GjJktKKuEScWaOXX(bool BYQhAOcHRUuLSvkg)?}) → void
IwmetjLmlBhCoDVj({required List<String> bziQtUQwwnoMJBAJ, void VBAYLsflJLTBgabI(bool BYQhAOcHRUuLSvkg)?, required void CFIVVzpAMeudhHXB(String user, YIMEnum_EventOnline event)}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited