YPushOption class
Constructors
- YPushOption({required String appKey, String? server, String? server_im, dynamic onSuccess(String deviceID)?})
Properties
- appKey ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- onSuccess ↔ dynamic Function(String deviceID)?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server ↔ String?
-
getter/setter pair
- server_im ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited