TUaQTtfebFZJqcPy class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cNVtxbRrkzgqokqv(
{required String rNMqkVPdAuizkpRy, required void lgljxLXuHiuEQGkB(bool zmXAhkEUrkMeoCEL, YIMRoom? room)}) → void -
edweafhoHgwRDFKw(
{required String rNMqkVPdAuizkpRy, required void lgljxLXuHiuEQGkB(bool zmXAhkEUrkMeoCEL)}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
ZYIZPcPtzOOlJrSg(
{required String rNMqkVPdAuizkpRy, required void lgljxLXuHiuEQGkB(bool zmXAhkEUrkMeoCEL)}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited