YCyzTHudsMFGbRdL class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
kRlwxTYILvIjEjWq(
{required String OYEhvWNusOUdbuCb, required void fDsWzZmHzuvhjHYF(bool vlIVOpmRlppDVoLJ, YIMTeam? team)}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sDaOHdpfIdCosqon(
{required void fDsWzZmHzuvhjHYF(List< String> ? IIYtzVoiSyjHgbQn)}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
vleIKhCuUivQeGUJ(
{required String OYEhvWNusOUdbuCb, void fDsWzZmHzuvhjHYF(bool vlIVOpmRlppDVoLJ)?}) → void -
XfqipmFJPkOrQtHq(
{required String OYEhvWNusOUdbuCb, void fDsWzZmHzuvhjHYF(bool vlIVOpmRlppDVoLJ)?}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited